# coding: utf-8

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from accessibletranslator.models.translation_response import TranslationResponse

class TestTranslationResponse(unittest.TestCase):
    """TranslationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TranslationResponse:
        """Test TranslationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TranslationResponse`
        """
        model = TranslationResponse()
        if include_optional:
            return TranslationResponse(
                translated_text = '',
                explanations = '',
                input_language = '',
                output_language = '',
                input_word_count = 56,
                processing_time_ms = 56,
                word_balance = 56,
                words_used = 56
            )
        else:
            return TranslationResponse(
                translated_text = '',
                input_language = '',
                output_language = '',
                input_word_count = 56,
                processing_time_ms = 56,
                word_balance = 56,
                words_used = 56,
        )
        """

    def testTranslationResponse(self):
        """Test TranslationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
