# coding: utf-8

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from accessibletranslator.models.target_languages_response import TargetLanguagesResponse

class TestTargetLanguagesResponse(unittest.TestCase):
    """TargetLanguagesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TargetLanguagesResponse:
        """Test TargetLanguagesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TargetLanguagesResponse`
        """
        model = TargetLanguagesResponse()
        if include_optional:
            return TargetLanguagesResponse(
                languages = [
                    ''
                    ],
                total_languages = 56,
                usage_note = ''
            )
        else:
            return TargetLanguagesResponse(
                languages = [
                    ''
                    ],
                total_languages = 56,
                usage_note = '',
        )
        """

    def testTargetLanguagesResponse(self):
        """Test TargetLanguagesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
