# coding: utf-8

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from accessibletranslator.api.user_management_api import UserManagementApi


class TestUserManagementApi(unittest.IsolatedAsyncioTestCase):
    """UserManagementApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = UserManagementApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_word_balance(self) -> None:
        """Test case for word_balance

        Get Word Balance
        """
        pass


if __name__ == '__main__':
    unittest.main()
