# coding: utf-8

"""
    AccessibleTranslator SDK API

    Official SDK API for AccessibleTranslator - automated cognitive accessibility

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from accessibletranslator.api.translation_api import TranslationApi


class TestTranslationApi(unittest.IsolatedAsyncioTestCase):
    """TranslationApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = TranslationApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_target_languages(self) -> None:
        """Test case for target_languages

        Get Available Target Languages
        """
        pass

    async def test_transformations(self) -> None:
        """Test case for transformations

        Get Available Transformations
        """
        pass

    async def test_translate(self) -> None:
        """Test case for translate

        Translate Text
        """
        pass


if __name__ == '__main__':
    unittest.main()
